LowerCase class

Implemented types

Constructors

LowerCase({required String value, String? attribute, String? customMessage})

Properties

attribute → String?
final
customMessage → String?
final
hashCode → int
The hash code for this object.
no setterinherited
instance → RuleProtocol
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
tryValidate() → String?
Validates the form field value
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited